# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 3.13.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CreateUserAuditTrailDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user_id': 'str',
        'entity_id': 'str',
        'entity_type': 'str',
        'entity_version': 'float',
        'entity_diff': 'object',
        'action': 'str'
    }

    attribute_map = {
        'user_id': 'userId',
        'entity_id': 'entityId',
        'entity_type': 'entityType',
        'entity_version': 'entityVersion',
        'entity_diff': 'entityDiff',
        'action': 'action'
    }

    def __init__(self, user_id=None, entity_id=None, entity_type=None, entity_version=None, entity_diff=None, action=None):  # noqa: E501
        """CreateUserAuditTrailDto - a model defined in Swagger"""  # noqa: E501
        self._user_id = None
        self._entity_id = None
        self._entity_type = None
        self._entity_version = None
        self._entity_diff = None
        self._action = None
        self.discriminator = None
        if user_id is not None:
            self.user_id = user_id
        self.entity_id = entity_id
        self.entity_type = entity_type
        self.entity_version = entity_version
        self.entity_diff = entity_diff
        self.action = action

    @property
    def user_id(self):
        """Gets the user_id of this CreateUserAuditTrailDto.  # noqa: E501


        :return: The user_id of this CreateUserAuditTrailDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this CreateUserAuditTrailDto.


        :param user_id: The user_id of this CreateUserAuditTrailDto.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def entity_id(self):
        """Gets the entity_id of this CreateUserAuditTrailDto.  # noqa: E501


        :return: The entity_id of this CreateUserAuditTrailDto.  # noqa: E501
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """Sets the entity_id of this CreateUserAuditTrailDto.


        :param entity_id: The entity_id of this CreateUserAuditTrailDto.  # noqa: E501
        :type: str
        """
        if entity_id is None:
            raise ValueError("Invalid value for `entity_id`, must not be `None`")  # noqa: E501

        self._entity_id = entity_id

    @property
    def entity_type(self):
        """Gets the entity_type of this CreateUserAuditTrailDto.  # noqa: E501


        :return: The entity_type of this CreateUserAuditTrailDto.  # noqa: E501
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this CreateUserAuditTrailDto.


        :param entity_type: The entity_type of this CreateUserAuditTrailDto.  # noqa: E501
        :type: str
        """
        if entity_type is None:
            raise ValueError("Invalid value for `entity_type`, must not be `None`")  # noqa: E501

        self._entity_type = entity_type

    @property
    def entity_version(self):
        """Gets the entity_version of this CreateUserAuditTrailDto.  # noqa: E501


        :return: The entity_version of this CreateUserAuditTrailDto.  # noqa: E501
        :rtype: float
        """
        return self._entity_version

    @entity_version.setter
    def entity_version(self, entity_version):
        """Sets the entity_version of this CreateUserAuditTrailDto.


        :param entity_version: The entity_version of this CreateUserAuditTrailDto.  # noqa: E501
        :type: float
        """
        if entity_version is None:
            raise ValueError("Invalid value for `entity_version`, must not be `None`")  # noqa: E501

        self._entity_version = entity_version

    @property
    def entity_diff(self):
        """Gets the entity_diff of this CreateUserAuditTrailDto.  # noqa: E501


        :return: The entity_diff of this CreateUserAuditTrailDto.  # noqa: E501
        :rtype: object
        """
        return self._entity_diff

    @entity_diff.setter
    def entity_diff(self, entity_diff):
        """Sets the entity_diff of this CreateUserAuditTrailDto.


        :param entity_diff: The entity_diff of this CreateUserAuditTrailDto.  # noqa: E501
        :type: object
        """
        if entity_diff is None:
            raise ValueError("Invalid value for `entity_diff`, must not be `None`")  # noqa: E501

        self._entity_diff = entity_diff

    @property
    def action(self):
        """Gets the action of this CreateUserAuditTrailDto.  # noqa: E501


        :return: The action of this CreateUserAuditTrailDto.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this CreateUserAuditTrailDto.


        :param action: The action of this CreateUserAuditTrailDto.  # noqa: E501
        :type: str
        """
        if action is None:
            raise ValueError("Invalid value for `action`, must not be `None`")  # noqa: E501
        allowed_values = ["created", "updated", "deleted"]  # noqa: E501
        if action not in allowed_values:
            raise ValueError(
                "Invalid value for `action` ({0}), must be one of {1}"  # noqa: E501
                .format(action, allowed_values)
            )

        self._action = action

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateUserAuditTrailDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateUserAuditTrailDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 3.13.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UpdateModelJobStatusDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'model_job_id': 'str',
        'project_id': 'str',
        'source': 'str',
        'step': 'str',
        'message': 'str',
        'type': 'str',
        'order': 'float',
        'progress': 'float',
        'metadata': 'object'
    }

    attribute_map = {
        'model_job_id': 'modelJobId',
        'project_id': 'projectId',
        'source': 'source',
        'step': 'step',
        'message': 'message',
        'type': 'type',
        'order': 'order',
        'progress': 'progress',
        'metadata': 'metadata'
    }

    def __init__(self, model_job_id=None, project_id=None, source=None, step=None, message=None, type=None, order=None, progress=None, metadata=None):  # noqa: E501
        """UpdateModelJobStatusDto - a model defined in Swagger"""  # noqa: E501
        self._model_job_id = None
        self._project_id = None
        self._source = None
        self._step = None
        self._message = None
        self._type = None
        self._order = None
        self._progress = None
        self._metadata = None
        self.discriminator = None
        if model_job_id is not None:
            self.model_job_id = model_job_id
        if project_id is not None:
            self.project_id = project_id
        if source is not None:
            self.source = source
        if step is not None:
            self.step = step
        if message is not None:
            self.message = message
        if type is not None:
            self.type = type
        if order is not None:
            self.order = order
        if progress is not None:
            self.progress = progress
        if metadata is not None:
            self.metadata = metadata

    @property
    def model_job_id(self):
        """Gets the model_job_id of this UpdateModelJobStatusDto.  # noqa: E501


        :return: The model_job_id of this UpdateModelJobStatusDto.  # noqa: E501
        :rtype: str
        """
        return self._model_job_id

    @model_job_id.setter
    def model_job_id(self, model_job_id):
        """Sets the model_job_id of this UpdateModelJobStatusDto.


        :param model_job_id: The model_job_id of this UpdateModelJobStatusDto.  # noqa: E501
        :type: str
        """

        self._model_job_id = model_job_id

    @property
    def project_id(self):
        """Gets the project_id of this UpdateModelJobStatusDto.  # noqa: E501


        :return: The project_id of this UpdateModelJobStatusDto.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this UpdateModelJobStatusDto.


        :param project_id: The project_id of this UpdateModelJobStatusDto.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def source(self):
        """Gets the source of this UpdateModelJobStatusDto.  # noqa: E501


        :return: The source of this UpdateModelJobStatusDto.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this UpdateModelJobStatusDto.


        :param source: The source of this UpdateModelJobStatusDto.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def step(self):
        """Gets the step of this UpdateModelJobStatusDto.  # noqa: E501


        :return: The step of this UpdateModelJobStatusDto.  # noqa: E501
        :rtype: str
        """
        return self._step

    @step.setter
    def step(self, step):
        """Sets the step of this UpdateModelJobStatusDto.


        :param step: The step of this UpdateModelJobStatusDto.  # noqa: E501
        :type: str
        """

        self._step = step

    @property
    def message(self):
        """Gets the message of this UpdateModelJobStatusDto.  # noqa: E501


        :return: The message of this UpdateModelJobStatusDto.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this UpdateModelJobStatusDto.


        :param message: The message of this UpdateModelJobStatusDto.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def type(self):
        """Gets the type of this UpdateModelJobStatusDto.  # noqa: E501


        :return: The type of this UpdateModelJobStatusDto.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this UpdateModelJobStatusDto.


        :param type: The type of this UpdateModelJobStatusDto.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def order(self):
        """Gets the order of this UpdateModelJobStatusDto.  # noqa: E501


        :return: The order of this UpdateModelJobStatusDto.  # noqa: E501
        :rtype: float
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this UpdateModelJobStatusDto.


        :param order: The order of this UpdateModelJobStatusDto.  # noqa: E501
        :type: float
        """

        self._order = order

    @property
    def progress(self):
        """Gets the progress of this UpdateModelJobStatusDto.  # noqa: E501


        :return: The progress of this UpdateModelJobStatusDto.  # noqa: E501
        :rtype: float
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this UpdateModelJobStatusDto.


        :param progress: The progress of this UpdateModelJobStatusDto.  # noqa: E501
        :type: float
        """

        self._progress = progress

    @property
    def metadata(self):
        """Gets the metadata of this UpdateModelJobStatusDto.  # noqa: E501


        :return: The metadata of this UpdateModelJobStatusDto.  # noqa: E501
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this UpdateModelJobStatusDto.


        :param metadata: The metadata of this UpdateModelJobStatusDto.  # noqa: E501
        :type: object
        """

        self._metadata = metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateModelJobStatusDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateModelJobStatusDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 3.13.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GeographicQueries(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'outcome_count_by_zip_query': 'str',
        'outcome_count_by_state_query': 'str',
        'cohort_count_by_zip_query': 'str',
        'cohort_count_by_state_query': 'str',
        'intervention_count_by_zip_query': 'str',
        'intervention_count_by_state_query': 'str'
    }

    attribute_map = {
        'outcome_count_by_zip_query': 'outcomeCountByZipQuery',
        'outcome_count_by_state_query': 'outcomeCountByStateQuery',
        'cohort_count_by_zip_query': 'cohortCountByZipQuery',
        'cohort_count_by_state_query': 'cohortCountByStateQuery',
        'intervention_count_by_zip_query': 'interventionCountByZipQuery',
        'intervention_count_by_state_query': 'interventionCountByStateQuery'
    }

    def __init__(self, outcome_count_by_zip_query=None, outcome_count_by_state_query=None, cohort_count_by_zip_query=None, cohort_count_by_state_query=None, intervention_count_by_zip_query=None, intervention_count_by_state_query=None):  # noqa: E501
        """GeographicQueries - a model defined in Swagger"""  # noqa: E501
        self._outcome_count_by_zip_query = None
        self._outcome_count_by_state_query = None
        self._cohort_count_by_zip_query = None
        self._cohort_count_by_state_query = None
        self._intervention_count_by_zip_query = None
        self._intervention_count_by_state_query = None
        self.discriminator = None
        if outcome_count_by_zip_query is not None:
            self.outcome_count_by_zip_query = outcome_count_by_zip_query
        if outcome_count_by_state_query is not None:
            self.outcome_count_by_state_query = outcome_count_by_state_query
        if cohort_count_by_zip_query is not None:
            self.cohort_count_by_zip_query = cohort_count_by_zip_query
        if cohort_count_by_state_query is not None:
            self.cohort_count_by_state_query = cohort_count_by_state_query
        if intervention_count_by_zip_query is not None:
            self.intervention_count_by_zip_query = intervention_count_by_zip_query
        if intervention_count_by_state_query is not None:
            self.intervention_count_by_state_query = intervention_count_by_state_query

    @property
    def outcome_count_by_zip_query(self):
        """Gets the outcome_count_by_zip_query of this GeographicQueries.  # noqa: E501


        :return: The outcome_count_by_zip_query of this GeographicQueries.  # noqa: E501
        :rtype: str
        """
        return self._outcome_count_by_zip_query

    @outcome_count_by_zip_query.setter
    def outcome_count_by_zip_query(self, outcome_count_by_zip_query):
        """Sets the outcome_count_by_zip_query of this GeographicQueries.


        :param outcome_count_by_zip_query: The outcome_count_by_zip_query of this GeographicQueries.  # noqa: E501
        :type: str
        """

        self._outcome_count_by_zip_query = outcome_count_by_zip_query

    @property
    def outcome_count_by_state_query(self):
        """Gets the outcome_count_by_state_query of this GeographicQueries.  # noqa: E501


        :return: The outcome_count_by_state_query of this GeographicQueries.  # noqa: E501
        :rtype: str
        """
        return self._outcome_count_by_state_query

    @outcome_count_by_state_query.setter
    def outcome_count_by_state_query(self, outcome_count_by_state_query):
        """Sets the outcome_count_by_state_query of this GeographicQueries.


        :param outcome_count_by_state_query: The outcome_count_by_state_query of this GeographicQueries.  # noqa: E501
        :type: str
        """

        self._outcome_count_by_state_query = outcome_count_by_state_query

    @property
    def cohort_count_by_zip_query(self):
        """Gets the cohort_count_by_zip_query of this GeographicQueries.  # noqa: E501


        :return: The cohort_count_by_zip_query of this GeographicQueries.  # noqa: E501
        :rtype: str
        """
        return self._cohort_count_by_zip_query

    @cohort_count_by_zip_query.setter
    def cohort_count_by_zip_query(self, cohort_count_by_zip_query):
        """Sets the cohort_count_by_zip_query of this GeographicQueries.


        :param cohort_count_by_zip_query: The cohort_count_by_zip_query of this GeographicQueries.  # noqa: E501
        :type: str
        """

        self._cohort_count_by_zip_query = cohort_count_by_zip_query

    @property
    def cohort_count_by_state_query(self):
        """Gets the cohort_count_by_state_query of this GeographicQueries.  # noqa: E501


        :return: The cohort_count_by_state_query of this GeographicQueries.  # noqa: E501
        :rtype: str
        """
        return self._cohort_count_by_state_query

    @cohort_count_by_state_query.setter
    def cohort_count_by_state_query(self, cohort_count_by_state_query):
        """Sets the cohort_count_by_state_query of this GeographicQueries.


        :param cohort_count_by_state_query: The cohort_count_by_state_query of this GeographicQueries.  # noqa: E501
        :type: str
        """

        self._cohort_count_by_state_query = cohort_count_by_state_query

    @property
    def intervention_count_by_zip_query(self):
        """Gets the intervention_count_by_zip_query of this GeographicQueries.  # noqa: E501


        :return: The intervention_count_by_zip_query of this GeographicQueries.  # noqa: E501
        :rtype: str
        """
        return self._intervention_count_by_zip_query

    @intervention_count_by_zip_query.setter
    def intervention_count_by_zip_query(self, intervention_count_by_zip_query):
        """Sets the intervention_count_by_zip_query of this GeographicQueries.


        :param intervention_count_by_zip_query: The intervention_count_by_zip_query of this GeographicQueries.  # noqa: E501
        :type: str
        """

        self._intervention_count_by_zip_query = intervention_count_by_zip_query

    @property
    def intervention_count_by_state_query(self):
        """Gets the intervention_count_by_state_query of this GeographicQueries.  # noqa: E501


        :return: The intervention_count_by_state_query of this GeographicQueries.  # noqa: E501
        :rtype: str
        """
        return self._intervention_count_by_state_query

    @intervention_count_by_state_query.setter
    def intervention_count_by_state_query(self, intervention_count_by_state_query):
        """Sets the intervention_count_by_state_query of this GeographicQueries.


        :param intervention_count_by_state_query: The intervention_count_by_state_query of this GeographicQueries.  # noqa: E501
        :type: str
        """

        self._intervention_count_by_state_query = intervention_count_by_state_query

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GeographicQueries, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GeographicQueries):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 3.13.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UpdateWorkflowExecutionDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'workflow_id': 'str',
        'run_id': 'float',
        'status': 'str',
        'queued_at': 'datetime',
        'started_at': 'datetime',
        'ended_at': 'datetime'
    }

    attribute_map = {
        'workflow_id': 'workflowId',
        'run_id': 'runId',
        'status': 'status',
        'queued_at': 'queuedAt',
        'started_at': 'startedAt',
        'ended_at': 'endedAt'
    }

    def __init__(self, workflow_id=None, run_id=None, status=None, queued_at=None, started_at=None, ended_at=None):  # noqa: E501
        """UpdateWorkflowExecutionDto - a model defined in Swagger"""  # noqa: E501
        self._workflow_id = None
        self._run_id = None
        self._status = None
        self._queued_at = None
        self._started_at = None
        self._ended_at = None
        self.discriminator = None
        if workflow_id is not None:
            self.workflow_id = workflow_id
        if run_id is not None:
            self.run_id = run_id
        if status is not None:
            self.status = status
        if queued_at is not None:
            self.queued_at = queued_at
        if started_at is not None:
            self.started_at = started_at
        if ended_at is not None:
            self.ended_at = ended_at

    @property
    def workflow_id(self):
        """Gets the workflow_id of this UpdateWorkflowExecutionDto.  # noqa: E501


        :return: The workflow_id of this UpdateWorkflowExecutionDto.  # noqa: E501
        :rtype: str
        """
        return self._workflow_id

    @workflow_id.setter
    def workflow_id(self, workflow_id):
        """Sets the workflow_id of this UpdateWorkflowExecutionDto.


        :param workflow_id: The workflow_id of this UpdateWorkflowExecutionDto.  # noqa: E501
        :type: str
        """

        self._workflow_id = workflow_id

    @property
    def run_id(self):
        """Gets the run_id of this UpdateWorkflowExecutionDto.  # noqa: E501


        :return: The run_id of this UpdateWorkflowExecutionDto.  # noqa: E501
        :rtype: float
        """
        return self._run_id

    @run_id.setter
    def run_id(self, run_id):
        """Sets the run_id of this UpdateWorkflowExecutionDto.


        :param run_id: The run_id of this UpdateWorkflowExecutionDto.  # noqa: E501
        :type: float
        """

        self._run_id = run_id

    @property
    def status(self):
        """Gets the status of this UpdateWorkflowExecutionDto.  # noqa: E501


        :return: The status of this UpdateWorkflowExecutionDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this UpdateWorkflowExecutionDto.


        :param status: The status of this UpdateWorkflowExecutionDto.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def queued_at(self):
        """Gets the queued_at of this UpdateWorkflowExecutionDto.  # noqa: E501


        :return: The queued_at of this UpdateWorkflowExecutionDto.  # noqa: E501
        :rtype: datetime
        """
        return self._queued_at

    @queued_at.setter
    def queued_at(self, queued_at):
        """Sets the queued_at of this UpdateWorkflowExecutionDto.


        :param queued_at: The queued_at of this UpdateWorkflowExecutionDto.  # noqa: E501
        :type: datetime
        """

        self._queued_at = queued_at

    @property
    def started_at(self):
        """Gets the started_at of this UpdateWorkflowExecutionDto.  # noqa: E501


        :return: The started_at of this UpdateWorkflowExecutionDto.  # noqa: E501
        :rtype: datetime
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this UpdateWorkflowExecutionDto.


        :param started_at: The started_at of this UpdateWorkflowExecutionDto.  # noqa: E501
        :type: datetime
        """

        self._started_at = started_at

    @property
    def ended_at(self):
        """Gets the ended_at of this UpdateWorkflowExecutionDto.  # noqa: E501


        :return: The ended_at of this UpdateWorkflowExecutionDto.  # noqa: E501
        :rtype: datetime
        """
        return self._ended_at

    @ended_at.setter
    def ended_at(self, ended_at):
        """Sets the ended_at of this UpdateWorkflowExecutionDto.


        :param ended_at: The ended_at of this UpdateWorkflowExecutionDto.  # noqa: E501
        :type: datetime
        """

        self._ended_at = ended_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateWorkflowExecutionDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateWorkflowExecutionDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 3.13.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ModelOutputDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'model_id': 'str',
        'latest_train_job_updated_at': 'datetime',
        'model_job_output_id': 'str',
        'model_job_id': 'str',
        'att_value': 'str',
        'att_direction': 'str',
        'att_se': 'str',
        'ate_value': 'str',
        'ate_direction': 'str',
        'ate_se': 'str',
        'top_impact_quartile_ate_value': 'str',
        'top_impact_quartile_ate_direction': 'str',
        'top_impact_quartile_se': 'str',
        'treated_records': 'float',
        'total_records': 'float',
        'n_features': 'float',
        'average_outcome_all': 'str',
        'average_outcome_treated': 'str',
        'average_outcome_untreated': 'str',
        'spearman_stability': 'str',
        'target_method': 'str',
        'r2': 'str',
        'auc': 'str',
        'n_records': 'float',
        'risk_average_outcome': 'str',
        'model': 'Model'
    }

    attribute_map = {
        'model_id': 'modelId',
        'latest_train_job_updated_at': 'latestTrainJobUpdatedAt',
        'model_job_output_id': 'modelJobOutputId',
        'model_job_id': 'modelJobId',
        'att_value': 'attValue',
        'att_direction': 'attDirection',
        'att_se': 'attSe',
        'ate_value': 'ateValue',
        'ate_direction': 'ateDirection',
        'ate_se': 'ateSe',
        'top_impact_quartile_ate_value': 'topImpactQuartileAteValue',
        'top_impact_quartile_ate_direction': 'topImpactQuartileAteDirection',
        'top_impact_quartile_se': 'topImpactQuartileSe',
        'treated_records': 'treatedRecords',
        'total_records': 'totalRecords',
        'n_features': 'nFeatures',
        'average_outcome_all': 'averageOutcomeAll',
        'average_outcome_treated': 'averageOutcomeTreated',
        'average_outcome_untreated': 'averageOutcomeUntreated',
        'spearman_stability': 'spearmanStability',
        'target_method': 'targetMethod',
        'r2': 'r2',
        'auc': 'auc',
        'n_records': 'n_records',
        'risk_average_outcome': 'riskAverageOutcome',
        'model': 'model'
    }

    def __init__(self, model_id=None, latest_train_job_updated_at=None, model_job_output_id=None, model_job_id=None, att_value=None, att_direction=None, att_se=None, ate_value=None, ate_direction=None, ate_se=None, top_impact_quartile_ate_value=None, top_impact_quartile_ate_direction=None, top_impact_quartile_se=None, treated_records=None, total_records=None, n_features=None, average_outcome_all=None, average_outcome_treated=None, average_outcome_untreated=None, spearman_stability=None, target_method=None, r2=None, auc=None, n_records=None, risk_average_outcome=None, model=None):  # noqa: E501
        """ModelOutputDetails - a model defined in Swagger"""  # noqa: E501
        self._model_id = None
        self._latest_train_job_updated_at = None
        self._model_job_output_id = None
        self._model_job_id = None
        self._att_value = None
        self._att_direction = None
        self._att_se = None
        self._ate_value = None
        self._ate_direction = None
        self._ate_se = None
        self._top_impact_quartile_ate_value = None
        self._top_impact_quartile_ate_direction = None
        self._top_impact_quartile_se = None
        self._treated_records = None
        self._total_records = None
        self._n_features = None
        self._average_outcome_all = None
        self._average_outcome_treated = None
        self._average_outcome_untreated = None
        self._spearman_stability = None
        self._target_method = None
        self._r2 = None
        self._auc = None
        self._n_records = None
        self._risk_average_outcome = None
        self._model = None
        self.discriminator = None
        self.model_id = model_id
        self.latest_train_job_updated_at = latest_train_job_updated_at
        self.model_job_output_id = model_job_output_id
        self.model_job_id = model_job_id
        self.att_value = att_value
        self.att_direction = att_direction
        self.att_se = att_se
        self.ate_value = ate_value
        self.ate_direction = ate_direction
        self.ate_se = ate_se
        self.top_impact_quartile_ate_value = top_impact_quartile_ate_value
        self.top_impact_quartile_ate_direction = top_impact_quartile_ate_direction
        self.top_impact_quartile_se = top_impact_quartile_se
        self.treated_records = treated_records
        self.total_records = total_records
        self.n_features = n_features
        self.average_outcome_all = average_outcome_all
        self.average_outcome_treated = average_outcome_treated
        self.average_outcome_untreated = average_outcome_untreated
        self.spearman_stability = spearman_stability
        self.target_method = target_method
        self.r2 = r2
        self.auc = auc
        self.n_records = n_records
        self.risk_average_outcome = risk_average_outcome
        if model is not None:
            self.model = model

    @property
    def model_id(self):
        """Gets the model_id of this ModelOutputDetails.  # noqa: E501


        :return: The model_id of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this ModelOutputDetails.


        :param model_id: The model_id of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if model_id is None:
            raise ValueError("Invalid value for `model_id`, must not be `None`")  # noqa: E501

        self._model_id = model_id

    @property
    def latest_train_job_updated_at(self):
        """Gets the latest_train_job_updated_at of this ModelOutputDetails.  # noqa: E501


        :return: The latest_train_job_updated_at of this ModelOutputDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._latest_train_job_updated_at

    @latest_train_job_updated_at.setter
    def latest_train_job_updated_at(self, latest_train_job_updated_at):
        """Sets the latest_train_job_updated_at of this ModelOutputDetails.


        :param latest_train_job_updated_at: The latest_train_job_updated_at of this ModelOutputDetails.  # noqa: E501
        :type: datetime
        """
        if latest_train_job_updated_at is None:
            raise ValueError("Invalid value for `latest_train_job_updated_at`, must not be `None`")  # noqa: E501

        self._latest_train_job_updated_at = latest_train_job_updated_at

    @property
    def model_job_output_id(self):
        """Gets the model_job_output_id of this ModelOutputDetails.  # noqa: E501


        :return: The model_job_output_id of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._model_job_output_id

    @model_job_output_id.setter
    def model_job_output_id(self, model_job_output_id):
        """Sets the model_job_output_id of this ModelOutputDetails.


        :param model_job_output_id: The model_job_output_id of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if model_job_output_id is None:
            raise ValueError("Invalid value for `model_job_output_id`, must not be `None`")  # noqa: E501

        self._model_job_output_id = model_job_output_id

    @property
    def model_job_id(self):
        """Gets the model_job_id of this ModelOutputDetails.  # noqa: E501


        :return: The model_job_id of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._model_job_id

    @model_job_id.setter
    def model_job_id(self, model_job_id):
        """Sets the model_job_id of this ModelOutputDetails.


        :param model_job_id: The model_job_id of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if model_job_id is None:
            raise ValueError("Invalid value for `model_job_id`, must not be `None`")  # noqa: E501

        self._model_job_id = model_job_id

    @property
    def att_value(self):
        """Gets the att_value of this ModelOutputDetails.  # noqa: E501


        :return: The att_value of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._att_value

    @att_value.setter
    def att_value(self, att_value):
        """Sets the att_value of this ModelOutputDetails.


        :param att_value: The att_value of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if att_value is None:
            raise ValueError("Invalid value for `att_value`, must not be `None`")  # noqa: E501

        self._att_value = att_value

    @property
    def att_direction(self):
        """Gets the att_direction of this ModelOutputDetails.  # noqa: E501


        :return: The att_direction of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._att_direction

    @att_direction.setter
    def att_direction(self, att_direction):
        """Sets the att_direction of this ModelOutputDetails.


        :param att_direction: The att_direction of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if att_direction is None:
            raise ValueError("Invalid value for `att_direction`, must not be `None`")  # noqa: E501

        self._att_direction = att_direction

    @property
    def att_se(self):
        """Gets the att_se of this ModelOutputDetails.  # noqa: E501


        :return: The att_se of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._att_se

    @att_se.setter
    def att_se(self, att_se):
        """Sets the att_se of this ModelOutputDetails.


        :param att_se: The att_se of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if att_se is None:
            raise ValueError("Invalid value for `att_se`, must not be `None`")  # noqa: E501

        self._att_se = att_se

    @property
    def ate_value(self):
        """Gets the ate_value of this ModelOutputDetails.  # noqa: E501


        :return: The ate_value of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._ate_value

    @ate_value.setter
    def ate_value(self, ate_value):
        """Sets the ate_value of this ModelOutputDetails.


        :param ate_value: The ate_value of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if ate_value is None:
            raise ValueError("Invalid value for `ate_value`, must not be `None`")  # noqa: E501

        self._ate_value = ate_value

    @property
    def ate_direction(self):
        """Gets the ate_direction of this ModelOutputDetails.  # noqa: E501


        :return: The ate_direction of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._ate_direction

    @ate_direction.setter
    def ate_direction(self, ate_direction):
        """Sets the ate_direction of this ModelOutputDetails.


        :param ate_direction: The ate_direction of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if ate_direction is None:
            raise ValueError("Invalid value for `ate_direction`, must not be `None`")  # noqa: E501

        self._ate_direction = ate_direction

    @property
    def ate_se(self):
        """Gets the ate_se of this ModelOutputDetails.  # noqa: E501


        :return: The ate_se of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._ate_se

    @ate_se.setter
    def ate_se(self, ate_se):
        """Sets the ate_se of this ModelOutputDetails.


        :param ate_se: The ate_se of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if ate_se is None:
            raise ValueError("Invalid value for `ate_se`, must not be `None`")  # noqa: E501

        self._ate_se = ate_se

    @property
    def top_impact_quartile_ate_value(self):
        """Gets the top_impact_quartile_ate_value of this ModelOutputDetails.  # noqa: E501


        :return: The top_impact_quartile_ate_value of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._top_impact_quartile_ate_value

    @top_impact_quartile_ate_value.setter
    def top_impact_quartile_ate_value(self, top_impact_quartile_ate_value):
        """Sets the top_impact_quartile_ate_value of this ModelOutputDetails.


        :param top_impact_quartile_ate_value: The top_impact_quartile_ate_value of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if top_impact_quartile_ate_value is None:
            raise ValueError("Invalid value for `top_impact_quartile_ate_value`, must not be `None`")  # noqa: E501

        self._top_impact_quartile_ate_value = top_impact_quartile_ate_value

    @property
    def top_impact_quartile_ate_direction(self):
        """Gets the top_impact_quartile_ate_direction of this ModelOutputDetails.  # noqa: E501


        :return: The top_impact_quartile_ate_direction of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._top_impact_quartile_ate_direction

    @top_impact_quartile_ate_direction.setter
    def top_impact_quartile_ate_direction(self, top_impact_quartile_ate_direction):
        """Sets the top_impact_quartile_ate_direction of this ModelOutputDetails.


        :param top_impact_quartile_ate_direction: The top_impact_quartile_ate_direction of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if top_impact_quartile_ate_direction is None:
            raise ValueError("Invalid value for `top_impact_quartile_ate_direction`, must not be `None`")  # noqa: E501

        self._top_impact_quartile_ate_direction = top_impact_quartile_ate_direction

    @property
    def top_impact_quartile_se(self):
        """Gets the top_impact_quartile_se of this ModelOutputDetails.  # noqa: E501


        :return: The top_impact_quartile_se of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._top_impact_quartile_se

    @top_impact_quartile_se.setter
    def top_impact_quartile_se(self, top_impact_quartile_se):
        """Sets the top_impact_quartile_se of this ModelOutputDetails.


        :param top_impact_quartile_se: The top_impact_quartile_se of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if top_impact_quartile_se is None:
            raise ValueError("Invalid value for `top_impact_quartile_se`, must not be `None`")  # noqa: E501

        self._top_impact_quartile_se = top_impact_quartile_se

    @property
    def treated_records(self):
        """Gets the treated_records of this ModelOutputDetails.  # noqa: E501


        :return: The treated_records of this ModelOutputDetails.  # noqa: E501
        :rtype: float
        """
        return self._treated_records

    @treated_records.setter
    def treated_records(self, treated_records):
        """Sets the treated_records of this ModelOutputDetails.


        :param treated_records: The treated_records of this ModelOutputDetails.  # noqa: E501
        :type: float
        """
        if treated_records is None:
            raise ValueError("Invalid value for `treated_records`, must not be `None`")  # noqa: E501

        self._treated_records = treated_records

    @property
    def total_records(self):
        """Gets the total_records of this ModelOutputDetails.  # noqa: E501


        :return: The total_records of this ModelOutputDetails.  # noqa: E501
        :rtype: float
        """
        return self._total_records

    @total_records.setter
    def total_records(self, total_records):
        """Sets the total_records of this ModelOutputDetails.


        :param total_records: The total_records of this ModelOutputDetails.  # noqa: E501
        :type: float
        """
        if total_records is None:
            raise ValueError("Invalid value for `total_records`, must not be `None`")  # noqa: E501

        self._total_records = total_records

    @property
    def n_features(self):
        """Gets the n_features of this ModelOutputDetails.  # noqa: E501


        :return: The n_features of this ModelOutputDetails.  # noqa: E501
        :rtype: float
        """
        return self._n_features

    @n_features.setter
    def n_features(self, n_features):
        """Sets the n_features of this ModelOutputDetails.


        :param n_features: The n_features of this ModelOutputDetails.  # noqa: E501
        :type: float
        """
        if n_features is None:
            raise ValueError("Invalid value for `n_features`, must not be `None`")  # noqa: E501

        self._n_features = n_features

    @property
    def average_outcome_all(self):
        """Gets the average_outcome_all of this ModelOutputDetails.  # noqa: E501


        :return: The average_outcome_all of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._average_outcome_all

    @average_outcome_all.setter
    def average_outcome_all(self, average_outcome_all):
        """Sets the average_outcome_all of this ModelOutputDetails.


        :param average_outcome_all: The average_outcome_all of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if average_outcome_all is None:
            raise ValueError("Invalid value for `average_outcome_all`, must not be `None`")  # noqa: E501

        self._average_outcome_all = average_outcome_all

    @property
    def average_outcome_treated(self):
        """Gets the average_outcome_treated of this ModelOutputDetails.  # noqa: E501


        :return: The average_outcome_treated of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._average_outcome_treated

    @average_outcome_treated.setter
    def average_outcome_treated(self, average_outcome_treated):
        """Sets the average_outcome_treated of this ModelOutputDetails.


        :param average_outcome_treated: The average_outcome_treated of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if average_outcome_treated is None:
            raise ValueError("Invalid value for `average_outcome_treated`, must not be `None`")  # noqa: E501

        self._average_outcome_treated = average_outcome_treated

    @property
    def average_outcome_untreated(self):
        """Gets the average_outcome_untreated of this ModelOutputDetails.  # noqa: E501


        :return: The average_outcome_untreated of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._average_outcome_untreated

    @average_outcome_untreated.setter
    def average_outcome_untreated(self, average_outcome_untreated):
        """Sets the average_outcome_untreated of this ModelOutputDetails.


        :param average_outcome_untreated: The average_outcome_untreated of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if average_outcome_untreated is None:
            raise ValueError("Invalid value for `average_outcome_untreated`, must not be `None`")  # noqa: E501

        self._average_outcome_untreated = average_outcome_untreated

    @property
    def spearman_stability(self):
        """Gets the spearman_stability of this ModelOutputDetails.  # noqa: E501


        :return: The spearman_stability of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._spearman_stability

    @spearman_stability.setter
    def spearman_stability(self, spearman_stability):
        """Sets the spearman_stability of this ModelOutputDetails.


        :param spearman_stability: The spearman_stability of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if spearman_stability is None:
            raise ValueError("Invalid value for `spearman_stability`, must not be `None`")  # noqa: E501

        self._spearman_stability = spearman_stability

    @property
    def target_method(self):
        """Gets the target_method of this ModelOutputDetails.  # noqa: E501


        :return: The target_method of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._target_method

    @target_method.setter
    def target_method(self, target_method):
        """Sets the target_method of this ModelOutputDetails.


        :param target_method: The target_method of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if target_method is None:
            raise ValueError("Invalid value for `target_method`, must not be `None`")  # noqa: E501

        self._target_method = target_method

    @property
    def r2(self):
        """Gets the r2 of this ModelOutputDetails.  # noqa: E501


        :return: The r2 of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._r2

    @r2.setter
    def r2(self, r2):
        """Sets the r2 of this ModelOutputDetails.


        :param r2: The r2 of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if r2 is None:
            raise ValueError("Invalid value for `r2`, must not be `None`")  # noqa: E501

        self._r2 = r2

    @property
    def auc(self):
        """Gets the auc of this ModelOutputDetails.  # noqa: E501


        :return: The auc of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._auc

    @auc.setter
    def auc(self, auc):
        """Sets the auc of this ModelOutputDetails.


        :param auc: The auc of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if auc is None:
            raise ValueError("Invalid value for `auc`, must not be `None`")  # noqa: E501

        self._auc = auc

    @property
    def n_records(self):
        """Gets the n_records of this ModelOutputDetails.  # noqa: E501


        :return: The n_records of this ModelOutputDetails.  # noqa: E501
        :rtype: float
        """
        return self._n_records

    @n_records.setter
    def n_records(self, n_records):
        """Sets the n_records of this ModelOutputDetails.


        :param n_records: The n_records of this ModelOutputDetails.  # noqa: E501
        :type: float
        """
        if n_records is None:
            raise ValueError("Invalid value for `n_records`, must not be `None`")  # noqa: E501

        self._n_records = n_records

    @property
    def risk_average_outcome(self):
        """Gets the risk_average_outcome of this ModelOutputDetails.  # noqa: E501


        :return: The risk_average_outcome of this ModelOutputDetails.  # noqa: E501
        :rtype: str
        """
        return self._risk_average_outcome

    @risk_average_outcome.setter
    def risk_average_outcome(self, risk_average_outcome):
        """Sets the risk_average_outcome of this ModelOutputDetails.


        :param risk_average_outcome: The risk_average_outcome of this ModelOutputDetails.  # noqa: E501
        :type: str
        """
        if risk_average_outcome is None:
            raise ValueError("Invalid value for `risk_average_outcome`, must not be `None`")  # noqa: E501

        self._risk_average_outcome = risk_average_outcome

    @property
    def model(self):
        """Gets the model of this ModelOutputDetails.  # noqa: E501


        :return: The model of this ModelOutputDetails.  # noqa: E501
        :rtype: Model
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this ModelOutputDetails.


        :param model: The model of this ModelOutputDetails.  # noqa: E501
        :type: Model
        """

        self._model = model

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ModelOutputDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelOutputDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
